@@ -750,7 +750,7 @@ pub async fn get_blob<S: AsRef<str>>(id: S, storage_container: &str) -> Result<V
     .as_blob_client(id.as_ref());
 
     match blob_client.get().execute().await {
-        Ok(r) => Ok(r.data),
+        Ok(r) => Ok(r.data.to_vec()),
         Err(err) => {
             return Err(new_cosmos_error_kind(
                 format!("Could not get blob from storage account {:?}", err),
